@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Exporter);
 
-our $VERSION = '0.023';
+our $VERSION = '0.024';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Tickit::DSL - domain-specific language for Tickit terminal apps
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
@@ -1332,19 +1332,9 @@ sub apply_widget {
 			$PARENT->set_base_child($w);
 		} elsif($PARENT->isa('Tickit::Widget::Layout::Desktop')) {
 			my %args = @WIDGET_ARGS;
-			my $dw = $PARENT->window;
-			my $left = $args{left} // int($dw->cols * rand);
-			my $top = $args{top} // int($dw->lines * rand);
-			my $cols = $args{cols} // (20 + int(10 * rand));
-			my $lines = $args{cols} // (5 + int(20 * rand));
-			$left = $dw->cols - $cols if $left + $cols >= $dw->cols;
-			$top = $dw->lines - $lines if $top + $lines >= $dw->lines;
 			$PARENT->create_panel(
-				label  => $args{label} // 'New window',
-				left   => $left,
-				top    => $top,
-				cols   => $cols,
-				lines  => $lines,
+				label  => 'New window',
+				%args,
 			)->add($w);
 		} else {
 			$PARENT->add($w, @WIDGET_ARGS);
